#!/bin/ksh 

#**********************************************************************
#*-------------------------------------------------------------------------------
#* Licensed Materials - Property of IBM
#*
#* 5724-A18
#*
#* (c) Copyright IBM Corp. 2000, 2001, 2002
#*
#* US Government Users Restricted Rights - Use, duplication or
#* disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#*-------------------------------------------------------------------------------
#
# set global variables 
#
SOFTWARE_PATCH="Software_Patches"
PTF2_DIR="WAS_fp2"
WAS401=0
WAS402=0
PROPDIR=/properties/com/ibm/websphere
WASEFIX_SOURCE=
WASEFIX_DESTINATION=/tmp/WebSphere/eFixes
LOGFILE=/tmp/wc54efixunix.log
HDREQ1K=337920 #330 MB
# Preset the WAS path by OS
OS_NAME=`uname`
DATE=`(/usr/bin/date)`

##
## Begin of script function
##

if [[ "$OS_NAME" = "AIX" ]];
then
   WAS_DIR=/usr/WebSphere/AppServer
   WCS_DIR=/usr/WebSphere/CommerceServer
   IHS_HOME=/usr/HTTPServer
   OS_SUFFIX=AIX
#=================== Begin Add by Mike ===================
   DBDIR=/usr/lpp/db2_07_01
   DBEXPORTHOME=/home
#===================  End Add by Mike  ===================   
elif [[ "$OS_NAME" = "SunOS" || "$OS_NAME" = "Solaris" ]];
then
   WAS_DIR=/opt/WebSphere/AppServer
   WCS_DIR=/opt/WebSphere/CommerceServer
   IHS_HOME=/opt/IBMHTTPServer
   OS_SUFFIX=SUN
#=================== Begin Add by Mike ===================
   DBDIR=/opt/IBMdb2/V7.1
   DBEXPORTHOME=/export/home
#===================  End Add by Mike  ===================
   
else
   echo "Unsupported platform: $OS_NAME" | tee ${LOGFILE}
   echo "Exiting ..." | tee ${LOGFILE}
   exit 1
fi

if [[ -d ${WCS_DIR}/logs ]];
then
   LOGFILE=${WCS_DIR}/logs/wc54efixunix.log
fi

if [[ -f ${LOGFILE} ]];
then
   /usr/bin/echo "" | tee -a ${LOGFILE}
   /usr/bin/echo "Begin wcpostinstall Script Execution:${DATE}" | tee -a ${LOGFILE}
else
   /usr/bin/echo "" > tee -a ${LOGFILE}
   /usr/bin/echo "Begin wcpostinstall Script Execution:${DATE}" | tee -a ${LOGFILE}
fi

###################################################################################################################
# ApplyPMR60732 -- function to ApplyPMR60732
###################################################################################################################
ApplyPMR60732()
{
if [[ "$OS_NAME" = "AIX" ]];
then

   if [[ ! -d ${WAS_DIR}/java/jre/lib/extfix ]];
   then
      /usr/bin/echo "Creating dir ${WAS_DIR}/java/jre/lib/extfix" | tee -a ${LOGFILE}
      /usr/bin/mkdir -p ${WAS_DIR}/java/jre/lib/extfix   
   else
      /usr/bin/echo "Dir already present: ${WAS_DIR}/java/jre/lib/extfix" | tee -a ${LOGFILE}
   fi

   if [[ -f ${WAS_DIR}/java/jre/lib/extfix/PMR60732.jar ]];
   then
      /usr/bin/echo "Backed up to ${WAS_DIR}/java/jre/lib/extfix/PMR60732.jar.$$" | tee -a ${LOGFILE}
      /usr/bin/cp ${WAS_DIR}/java/jre/lib/extfix/PMR60732.jar ${WAS_DIR}/java/jre/lib/extfix/PMR60732.jar.$$
   fi

   /usr/bin/echo "Copying to ${WAS_DIR}/java/jre/lib/extfix/PMR60732.jar" | tee -a ${LOGFILE}
   /usr/bin/cp ${WASEFIX_SOURCE}/${SOFTWARE_PATCH}/WAS_efixes/PMR60732.jar ${WAS_DIR}/java/jre/lib/extfix/PMR60732.jar

   if [[ -f ${WAS_DIR}/java/jre/lib/bootclass.path ]];
   then
      # Path exists, append to it if not present already

      TEMP=`( /usr/bin/grep "${WAS_DIR}/java/jre/lib/extfix/PMR60732.jar" ${WAS_DIR}/java/jre/lib/bootclass.path )`
      if [[ $? -ne 0 ]];
      then
         /usr/bin/echo "Adding ${WAS_DIR}/java/jre/lib/extfix/PMR60732.jar to ${WAS_DIR}/java/jre/lib/bootclass.path" | tee -a ${LOGFILE}
         /usr/bin/cp ${WAS_DIR}/java/jre/lib/bootclass.path ${WAS_DIR}/java/jre/lib/bootclass.path.$$

         #
         # This is based on one long continuous line for the PATH. So only 1 line.
         #
         NUMLINES=`(grep -c -v "THISISJUSTTOCOUNTLINES" ${WAS_DIR}/java/jre/lib/bootclass.path)`
         if [[ NUMLINES -eq 0 ]];
         then
            # File is blank so just add to it
            /usr/bin/echo "Adding to ${WAS_DIR}/java/jre/lib/bootclass.path" | tee -a ${LOGFILE}
            /usr/bin/echo "${WAS_DIR}/java/jre/lib/extfix/PMR60732.jar" >> ${WAS_DIR}/java/jre/lib/bootclass.path
         elif [[ NUMLINES -eq 1 ]];
         then
            /usr/bin/sed "s|^|${WAS_DIR}/java/jre/lib/extfix/PMR60732.jar:|" ${WAS_DIR}/java/jre/lib/bootclass.path.$$ > ${WAS_DIR}/java/jre/lib/bootclass.path
         else
            /usr/bin/echo "ERROR: bootclass.path has more than one line. Please manually add the value" | tee -a ${LOGFILE}
            /usr/bin/echo "/"${WAS_DIR}/java/jre/lib/extfix/PMR60732.jar:/" to the front of the jar path" | tee -a ${LOGFILE}
         fi
      else
         /usr/bin/echo "Skipping edit of ${WAS_DIR}/java/jre/lib/bootclass.path. Path present" | tee -a ${LOGFILE}
      fi
   else
      # New file to be created
      /usr/bin/echo "Creating ${WAS_DIR}/java/jre/lib/bootclass.path" | tee -a ${LOGFILE}
      /usr/bin/echo "${WAS_DIR}/java/jre/lib/extfix/PMR60732.jar" > ${WAS_DIR}/java/jre/lib/bootclass.path
   fi
fi
}
###################################################################################################################
# CheckIHSWASStopped -- function to check if IHS and WAS is stopped, issue error and exit if not
###################################################################################################################
CheckIHSWASStopped()
{
# check IHS processes
ps -ef | grep "$IHS_HOME/bin/httpd" | grep -v $$

if [[ $? -ne 1 ]];
then
   /usr/bin/echo "ERROR: IBM HTTP Server is not stopped," | tee -a ${LOGFILE}
   /usr/bin/echo "     please stop your IBM HTTP Server before continuing. "| tee -a ${LOGFILE}
   exit 1
fi
# check WAS processes
ps -ef | grep "java" | grep -v $$

if [[ $? -ne 1 ]];
then
   /usr/bin/echo "ERROR: IBM WebSphere Application Server is not stopped," | tee -a ${LOGFILE}
   /usr/bin/echo "     please stop your WAS AE and any Java related process before continuing. "| tee -a ${LOGFILE}
   exit 1
fi
}

###################################################################################################################
# ApplyWAS401PTF2 -- function to apply WAS401PTF2
###################################################################################################################
ApplyWAS401PTF2()
{
while :
do
############### should add the check for disk space requirement, min 110 MB
   /usr/bin/echo "************************************************************" | tee -a ${LOGFILE}
   /usr/bin/echo "**************** SPACE REQUIREMENTS ************************" | tee -a ${LOGFILE}
   /usr/bin/echo "* Please ensure there are 330 MB temporary space available *" | tee -a ${LOGFILE}
   /usr/bin/echo "* before proceeding to this PTF installation.              *" | tee -a ${LOGFILE} 
   /usr/bin/echo "************************************************************" | tee -a ${LOGFILE}
   read JUNK?"Press Enter to continue or type \"quit\" to exit this upgrade program: "
   if [[ "${JUNK}" = "quit" ]];
   then
      read JUNK?"Press enter to continue."
      exit 0
   else
      break;
   fi   
done   
# read in the source of WAS401PTF2 to copy from
# note the directory name was_402_fp_only may be changed on CD, check with build team.
   
   WASPTF_SOURCE=${WASEFIX_SOURCE}
   if [[ -d ${WASPTF_SOURCE}/${SOFTWARE_PATCH}/${PTF2_DIR} ]];
   then
      /usr/bin/echo ""
   else
      /usr/bin/echo "ERROR: Mount/Directory ${WASPTF_SOURCE}/${SOFTWARE_PATCH}/${PTF2_DIR} NOT FOUND." | tee -a ${LOGFILE}
      /usr/bin/echo "" | tee -a ${LOGFILE}
      continue
   fi

# untar PTF tar file
PTF_TAR="was40_ae_ptf_2"_${OS_SUFFIX}.tar
tar -xvf ${WASPTF_SOURCE}/${SOFTWARE_PATCH}/${PTF2_DIR}/${PTF_TAR}

# check IHS and WAS are stopped
#
CheckIHSWASStopped

# set the environment variables prior to performing silent install
export WAS_DIR
export IHS_INSTALL=true
export IHS_HOME
# running PTF installation script silently
$PWD/install.sh -silent

if [[ $? -ne 0 ]];
then
   /usr/bin/echo "ERROR: error encountered during WAS PTF2 installation," | tee -a ${LOGFILE}
   /usr/bin/echo "     please review ${WAS_DIR}/logs/was40_ae_ptf_2.log for details. "| tee -a ${LOGFILE}
   exit 1
fi
}
###################################################################################################################
# RemoveWAS401Efixes -- function to remove remaining WAS401 efixes 
###################################################################################################################
RemoveWAS401Efixes()
{
# check IHS and WAS are stopped
#
CheckIHSWASStopped

for X in ${EFIXES401[@]}
do 
  if [[ -d ${WAS_DIR}/eFix/$X ]];     
  then
     # these two efixes have special suffixes for their backup jars
     if [[ $X = "PQ55060" ]] || [[ $X = "PQ55064" ]];
     then
        EFIX_UNINSTALL_SUFFIX="eFix_AEServer_backup.jar"
     elif [[ $X = "PQ54634" ]] || [[ $X = "PQ54943" ]];
     then
        EFIX_UNINSTALL_SUFFIX="eFix_AEsServer_AEServer_backup.jar"
     else
        EFIX_UNINSTALL_SUFFIX="eFix_AEServer_AEsServer_backup.jar"
     fi
     /usr/bin/echo "Removing Efix $X for WAS401, please wait..." | tee -a ${LOGFILE}
     # double check the command to remove efixes!!
     ${JAVA_EXE} -jar \
       ${WAS_DIR}/eFix/${X}/${X}_${EFIX_UNINSTALL_SUFFIX}
        # error handling, exiting?
        if [[ $? -ne 0 ]];
	then
   	/usr/bin/echo "ERROR: error encountered during WAS 4.0.1 Efix $X uninstallation," | tee -a ${LOGFILE}
   	/usr/bin/echo "     please review ${WAS_DIR}/eFix/${X}/Extractor.log for details. "| tee -a ${LOGFILE}
   	exit 1
        fi
  else
     /usr/bin/echo "No such directory, ${WAS_DIR}/eFix/$X" | tee -a ${LOGFILE}
  fi
done
}
###################################################################################################################
# ApplyWAS402Efixes -- function to apply WAS402 efixes needed
###################################################################################################################
ApplyWAS402Efixes()
{
# check IHS and WAS are stopped
#
CheckIHSWASStopped


EFIX_INSTALL_SUFFIX="eFix_AEServer_AEsServer.jar"

/usr/bin/echo ""
/usr/bin/echo "${WAS_VER} AE Install Dir: ${WAS_DIR}"

/usr/bin/echo ""
/usr/bin/echo "Proceed with installation of eFixes ? (Y/N)"
/usr/bin/echo ""
read TEMP?":"

if [[ "${TEMP}" = "quit" ]];
then
   read JUNK?"Press enter to continue."
   exit 0
fi

if [[ "$TEMP" = "Y" || "$TEMP" = "y" ]];
then
   /usr/bin/echo "Proceeding with installation ..." | tee -a ${LOGFILE}
   /usr/bin/echo ""
else
   /usr/bin/echo "Exiting ..." | tee -a ${LOGFILE}
   exit 0
fi

if [[ -d ${WASEFIX_DESTINATION} ]];
then
   /usr/bin/echo "" | tee -a ${LOGFILE}
else
   /usr/bin/echo ""
   /usr/bin/echo "The destination dir of ${WASEFIX_DESTINATION} does not exist. Create (Y/N)"
   /usr/bin/echo ""
   read TEMP?":"

   if [[ "${TEMP}" = "quit" ]];
   then
      read JUNK?"Press enter to continue."
      exit 0
   fi

   if [[ "$TEMP" = "Y" || "$TEMP" = "y" ]];
   then
      /usr/bin/mkdir -p ${WASEFIX_DESTINATION}
   else
      /usr/bin/echo ""
      /usr/bin/echo "A destination dir of ${WASEFIX_DESTINATION} is required." | tee -a ${LOGFILE}
      /usr/bin/echo "If you desire another directory to place these eFixes, please edit" | tee -a ${LOGFILE}
      /usr/bin/echo "WASEFIX_DESTINATION at the top of this script and rerun." | tee -a ${LOGFILE}
      /usr/bin/echo "Exiting ..." | tee -a ${LOGFILE}
   exit 0
   fi
fi

# copy efixes from source to destination
/usr/bin/echo "Copying WebSphere Application eFixes to ${WASEFIX_DESTINATION}" | tee -a ${LOGFILE}
/usr/bin/cp ${WASEFIX_SOURCE}/${SOFTWARE_PATCH}/WAS_efixes/* ${WASEFIX_DESTINATION}

for X in ${EFIXES402[*]}
do 
  if [[ $X = "PMR60732" ]];
  then
  	ApplyPMR60732
  else		
   # different suffixes for different efixes
  if [[ $X = "PQ54291" ]];
  then
     EFIX_INSTALL_SUFFIX="eFix_AEServer_AEsServer.jar"
  elif [[ $X = "PQ57814" ]];
  then
     EFIX_INSTALL_SUFFIX="eFix_AEServer.jar"
  elif [[ $X = "PQ58443" ]];
  then
     EFIX_INSTALL_SUFFIX="eFix.jar"
  fi
 /usr/bin/echo "Installing Efixes $X for WAS402, please wait..." | tee -a ${LOGFILE} 
 ${JAVA_EXE} -jar \
   ${WASEFIX_DESTINATION}/${X}_${EFIX_INSTALL_SUFFIX} -target ${WAS_DIR}
   # error handling, exiting?
   if [[ $? -ne 0 ]];
   then
      /usr/bin/echo "ERROR: error encountered during WAS 4.0.2 Efix $X installation," | tee -a ${LOGFILE}
      /usr/bin/echo "     please review ${WAS_DIR}/eFix/${X}/Extractor.log for details. "| tee -a ${LOGFILE}
      exit 1
   fi
   fi
done



}

###################################################################################################################
# Beginning of Main Script
###################################################################################################################
while :
do
   /usr/bin/echo "**********************************************************" | tee -a ${LOGFILE}
   /usr/bin/echo "* Please ensure WebSphere Application Server AE,         *" | tee -a ${LOGFILE}
   /usr/bin/echo "* your webserver, and any Java related processes are     *" | tee -a ${LOGFILE}
   /usr/bin/echo "* stopped before continuing. Once the eFixes are applied *" | tee -a ${LOGFILE}
   /usr/bin/echo "* they can be restarted.                                 *" | tee -a ${LOGFILE}
if [[ "$OS_NAME" = "AIX" ]];
then
   /usr/bin/echo "* Please run /usr/sbin/slibclean to clear loaded libs    *" | tee -a ${LOGFILE}
fi
   /usr/bin/echo "* A log is generated in $LOGFILE                *" | tee -a ${LOGFILE}
   /usr/bin/echo "*                                                        *" | tee -a ${LOGFILE}
   /usr/bin/echo "* Please specify the source directory or mount point for *" | tee -a ${LOGFILE}
   /usr/bin/echo "* the WebSphere Application Server 5.4 eFixes            *" | tee -a ${LOGFILE}
   /usr/bin/echo "* ie: /cdrom/cdrom0                                      *" | tee -a ${LOGFILE}
   /usr/bin/echo "* ie: /dev/cdrom0                                        *" | tee -a ${LOGFILE}
   /usr/bin/echo "*                                                        *" | tee -a ${LOGFILE}
   /usr/bin/echo "* Enter: quit to exit this loop                          *" | tee -a ${LOGFILE}
   /usr/bin/echo "**********************************************************" | tee -a ${LOGFILE}
# read in the source of WASEifxes to copy from
   read WASEFIX_SOURCE?"Please enter the source point for the EFIX: "

   if [[ "${WASEFIX_SOURCE}" = "quit" ]];
   then
      read JUNK?"Press enter to continue."
      exit 0
   fi

   if [[ "${WASEFIX_SOURCE}" = "" ]];
   then
      continue
   fi

   if [[ -d ${WASEFIX_SOURCE}/${SOFTWARE_PATCH}/WAS_efixes ]];
   then
      /usr/bin/echo ""
   else
      /usr/bin/echo "ERROR: Mount/Directory ${WASEFIX_SOURCE}/${SOFTWARE_PATCH}/WAS_efixes NOT FOUND." | tee -a ${LOGFILE}
      /usr/bin/echo "" | tee -a ${LOGFILE}
      continue
   fi
# read user input of WAS Home directory
   read CHECK_DIR?"Please enter the WAS HOME directory [Default:$WAS_DIR]:"

   if [[ "${CHECK_DIR}" = "quit" ]];
   then
      read JUNK?"Press enter to continue."
      exit 0
   fi

   if [[ "${CHECK_DIR}" = "" ]];
   then
      CHECK_DIR=$WAS_DIR
   fi

   if [[ -d ${CHECK_DIR} ]];
   then
      WAS_DIR=$CHECK_DIR
      /usr/bin/echo "Using WAS HOME of $WAS_DIR" | tee -a ${LOGFILE}
      break;
   else
      /usr/bin/echo "Invalid entry of $CHECK_DIR" | tee -a ${LOGFILE}
      continue
   fi

done
# check WAS directory is there
if [[ ! -d ${WAS_DIR} ]];
then
   /usr/bin/echo "ERROR: Directory ${WAS_DIR} NOT FOUND. Please ensure WebSphere Application Server AE is installed." | tee -a ${LOGFILE}
   exit 1
fi
if [[ ! -d ${WAS_DIR}/bin || ! -d ${WAS_DIR}/lib ]];
then
   /usr/bin/echo "ERROR: Directory ${WAS_DIR}/bin or ${WAS_DIR}/lib NOT FOUND. Please ensure WebSphere Application Server is installed." | tee -a ${LOGFILE}
   exit 1
fi
# check WAS version
TEMP=`(/usr/bin/grep "<value>AE</value>" ${WAS_DIR}/properties/com/ibm/websphere/product.xml)`
if [[ $? -ne 0 ]];
then
   /usr/bin/echo "ERROR: WebSphere Application Server NOT DETECTED." | tee -a ${LOGFILE}
   exit 1
fi

TEMP=`(/usr/bin/grep "<version>4.0.2</version>" ${WAS_DIR}/properties/com/ibm/websphere/product.xml)`
if [[ $? -ne 0 ]];
then
   TEMP=`(/usr/bin/grep "<version>4.0.1</version>" ${WAS_DIR}/properties/com/ibm/websphere/product.xml)`
    
   if [[ $? -ne 0 ]];
   then
       /usr/bin/echo "ERROR: WebSphere Application Server 4.0 NOT DETECTED." | tee -a ${LOGFILE}
       exit 1
   else
       WAS401=1  
       WAS_VER="WAS 4.0.1"
       # /usr/bin/echo "WAS401="$WAS401 | tee -a ${LOGFILE}
   fi
else
   WAS402=1
   WAS_VER="WAS 4.0.2"
   # /usr/bin/echo "WAS402="$WAS402 | tee -a ${LOGFILE}
fi


#
# Run Efixes class in wcsinstall.jar to produce two log files
#
# set classpath first
CP1=$WAS_DIR/lib/xerces.jar
CP2=$WCS_DIR/lib/wcsinstall.jar
CP3=$WCS_DIR/lib/wcsconfig.jar
CP4=$WCS_DIR/lib/xml4j.jar
export JAVA_HOME=$WAS_DIR/java/jre
export JAVA_EXE=$JAVA_HOME/bin/java
export CLASSPATH=$CP1:$CP2:$CP3:$CP4:$CLASSPATH
cp $WAS_DIR$PROPDIR/product.dtd $PWD
PARAM1=$WAS_DIR$PROPDIR/product.xml
PARAM2=$WCS_DIR/xml/WASEfixes.xml
PARAM3=$WCS_DIR/logs/402efixes.log
PARAM4=$WCS_DIR/logs/401efixes.log 
# run Efixes Checker
${JAVA_EXE} \
-classpath $CLASSPATH \
com.ibm.commerce.install.Efixes $PARAM1 $PARAM2 $PARAM3 $PARAM4

   # error handling, exiting?
   if [[ $? -ne 0 ]];
   then
      /usr/bin/echo "ERROR: error encountered during Efix Checker execution," | tee -a ${LOGFILE}
      exit 1
   fi
# reading the list of efixes from two log files
# /usr/bin/echo "Before, reading file "$PARAM3 | tee -a ${LOGFILE}
exec 3<$PARAM3
read -u3 TOTAL402
# /usr/bin/echo "total = "$TOTAL402 | tee -a ${LOGFILE}
integer LOOPNUM=0
while read -u3 LINE
do 	
 # print $LOOPNUM
  EFIXES402[$LOOPNUM]=$LINE
  ((LOOPNUM+=1))
done
#for X in ${EFIXES402[*]}
#do 
#  /usr/bin/echo "Efixes: $X" | tee -a ${LOGFILE}
#done
#/usr/bin/echo "Before, reading file "$PARAM4 | tee -a ${LOGFILE}
exec 4<$PARAM4
read -u4 TOTAL401
#/usr/bin/echo "total = "$TOTAL401 > tee -a ${LOGFILE}
LOOPNUM=0
while read -u4 LINE
do 
  # print $LOOPNUM
  EFIXES401[$LOOPNUM]=$LINE
  ((LOOPNUM+=1))
done

#for X in ${EFIXES401[@]}
#do 
#  /usr/bin/echo "Efixes: $X" > tee -a ${LOGFILE}
#done
# if WAS402, check any remaining efixes from WAS401
if [ $WAS402 -eq 1 ];
then
   /usr/bin/echo "WebSphere Application Server 4.0.2 AE detected on the system." | tee -a ${LOGFILE}
   # any remaining efixes from WAS401?
   if [[ $TOTAL401 != 0 ]];
   then
	/usr/bin/echo "WARNING: WebSphere Application Server 4.0.2 AE is not installed properly, " | tee -a ${LOGFILE}
        
	/usr/bin/echo "please reinstall WebSphere Application Server FixPak 2," | tee -a ${LOGFILE}

	/usr/bin/echo "and ensure all WAS 4.0.1 Efixes are removed before reinstallation." | tee -a ${LOGFILE}
        /usr/bin/echo "This Script is now exiting" | tee -a ${LOGFILE}
        exit 1;
   else 
        /usr/bin/echo "WAS 4.0.2 is installed properly." | tee -a ${LOGFILE}
       # check any missing WAS 402 Efixes needed to be applied?
       if [[ $TOTAL402 = 0 ]];
       then
          /usr/bin/echo "All Efixes needed for WAS402 have been applied," | tee -a ${LOGFILE}
         # /usr/bin/echo "This Script is now exiting" | tee -a ${LOGFILE}
	 # exit 1;
       else
         /usr/bin/echo "Proceed with WAS402 EFixes Installation, please wait..." | tee -a ${LOGFILE}


       ##### # insert function to apply WAS402 Efixes
       ApplyWAS402Efixes
        # error handling, exiting?
        if [[ $? -ne 0 ]];
	then
   	   /usr/bin/echo "exiting..."| tee -a ${LOGFILE}
   	   exit 1
        fi
       fi  
   fi
else
   /usr/bin/echo "" | tee -a ${LOGFILE}
   /usr/bin/echo "WebSphere Application Server 4.0.1 AE detected on the system." | tee -a ${LOGFILE}
   # check remaining from WAS401 to remove
   if [[ $TOTAL401 != 0 ]];
   then
      /usr/bin/echo "Removing WAS4.0.1 Efixes from the system, please wait..." | tee -a ${LOGFILE}
     #### # insert function to remove WAS401 Efixes 
     RemoveWAS401Efixes
        # error handling, exiting?
        if [[ $? -ne 0 ]];
	then
   	   /usr/bin/echo "exiting... "| tee -a ${LOGFILE}
   	exit 1
        fi
   fi 
   # here is clean 4.0.1, install fixpak 2 PTF
      /usr/bin/echo "NO WAS4.0.1 Efixes remaining on the system, next install fixpak 2 for WAS4.0" | tee -a ${LOGFILE}
     #### # insert function to install WAS4.0.1Ptf2
     ApplyWAS401PTF2
        # error handling, exiting?
        if [[ $? -ne 0 ]];
	then
   	   /usr/bin/echo "exiting... "| tee -a ${LOGFILE}
   	exit 1
        fi
     
   # here is WAS4.0.2, apply any efixes needed for 4.0.2
   if [[ $TOTAL402 = 0 ]];
   then
      /usr/bin/echo "" | tee -a ${LOGFILE}
      /usr/bin/echo "" | tee -a ${LOGFILE}
      /usr/bin/echo "All Efixes needed for WAS402 have been applied," | tee -a ${LOGFILE}
      #/usr/bin/echo "This Script is now exiting." | tee -a ${LOGFILE}
      # exit 1;
   else
     /usr/bin/echo "Proceed with WAS402 EFixes Installation, please wait..." | tee -a ${LOGFILE}
     #### # insert function to apply WAS402 Efixes
     ApplyWAS402Efixes
        # error handling, exiting?
        if [[ $? -ne 0 ]];
	then
   	   /usr/bin/echo "exiting.. "| tee -a ${LOGFILE}
   	exit 1
        fi
   fi  
fi  

/usr/bin/echo "" | tee -a ${LOGFILE}
/usr/bin/echo "" | tee -a ${LOGFILE}

/usr/bin/echo "FINISHED: WebSphere Application Server 4.0 eFix installation complete." | tee -a ${LOGFILE}

#=================== Begin Add by Mike ===================

/usr/bin/echo "" | tee -a ${LOGFILE}
/usr/bin/echo "" | tee -a ${LOGFILE}
if [[ "$OS_NAME" = "SunOS" || "$OS_NAME" = "Solaris" ]];
then
   /usr/bin/echo "**********************************************************" | tee -a ${LOGFILE}
   /usr/bin/echo "* SUN JDK 1.3.1.01 UPGRADE INSTALL                       *" | tee -a ${LOGFILE}
   /usr/bin/echo "**********************************************************" | tee -a ${LOGFILE}

#===UPDATED BY BORIS FEB18/02
   JDKVER=`( ${WAS_DIR}/java/bin/java -version 2>&1 | grep java | awk '{print $3}') | awk -v '{FS="\""}{print $2}'`
   /usr/bin/echo "WAS Directory " $WAS_DIR
   /usr/bin/echo "JDK Version found is " $JDKVER
   if [[ "$JDKVER" = "1.3.1_01" ]];
   then
       /usr/bin/echo "JDK Version 1.3.1_01 already present.  Upgrade will NOT occur... "
       JDKUPGRADE="0"
   else
       /usr/bin/echo "JDK Version 1.3.1_01 NOT present.  Verifying the existence of JDK backup directory from previous run..."
       JDKORIDIR=${WAS_DIR}/java.ori
       if [[ -d ${JDKORIDIR} ]];
       then
           /usr/bin/echo "Backup directory ${JDKORIDIR} exists. JDK will NOT be upgraded"
           JDKUPGRADE="0"
       else
          /usr/bin/echo "Backup directory ${JDKORIDIR} NOT detected.  Continuing with upgrade..."
          JDKUPGRADE="1"
       fi
   fi
   if [[ "${JDKUPGRADE}" = "1" ]];
   then
	   NEW_JDK_SRC=${WASEFIX_SOURCE}/Software_Patches/SUNJDK1.3.1.01/Solaris
	   if [[ -d ${NEW_JDK_SRC} ]];
	   then
	      /usr/bin/echo "" | tee -a ${LOGFILE}
	   else
	      /usr/bin/echo "ERROR: Directory ${NEW_JDK_SRC} does not exist" | tee -a ${LOGFILE}
	      exit 1
	   fi
	
	   cd ${NEW_JDK_SRC}
	
	   #unzip the new JDK, it will create a directory jdk1.3.1
	   cd ${WAS_DIR}
	
	   /usr/bin/echo "Unzipping new JDK files..." | tee -a ${LOGFILE}
	   unzip ${NEW_JDK_SRC}/jdk-1_3_1_01-fcs-bin-solsparc-08_aug_2001.zip -d ${WAS_DIR}
	
	   #Merge the old and the new JDK
	   /usr/bin/echo "Merging the old and new JDK, please wait...." | tee -a ${LOGFILE}
	   cd ${WAS_DIR}
	   if [[ -d java131 ]];
	   then
	      cp -r java131 java131.ori
	   fi
	   cp -r java java131
	   cp -r jdk1.3.1/* java131
	   cp ./java/jre/lib/security/java.security ./java131/jre/lib/security
	
	   #Replace the existing JDK directory (either you do this or edit the admin.config to point to your new JDK location)
	
	   cd ${WAS_DIR}
	   /usr/bin/echo "Moving java files...." | tee -a ${LOGFILE}
	   mv java java.ori
	   /usr/bin/echo "Creating soft link to java directory" | tee -a ${LOGFILE}
	   ln -sf java131 java
	
	   #check java version
	   /usr/bin/echo "Verifying new java version" | tee -a ${LOGFILE}
	   cd ${WAS_DIR}/java/bin
	   ./java -version
   fi
   #===END OF UPDATE BY BORIS FEB18/02

   /usr/bin/echo "FINISHED: SUN JDK 1.3.1.01 Upgrade Install Complete." | tee -a ${LOGFILE}
   /usr/bin/echo "" | tee -a ${LOGFILE}
   /usr/bin/echo "" | tee -a ${LOGFILE}

fi

#===================  End Add by Mike  ===================

#=================== Begin Add by Mike ===================

while :
do
   /usr/bin/echo "**********************************************************" | tee -a ${LOGFILE}
   /usr/bin/echo "* Please ensure IBM DB2 and all services are stopped,    *" | tee -a ${LOGFILE}
   /usr/bin/echo "* The script will add usejdbc2 to your db2instance       *" | tee -a ${LOGFILE}
   /usr/bin/echo "* .profile if not present already.                       *" | tee -a ${LOGFILE}
   /usr/bin/echo "* A log is generated in $LOGFILE                         *" | tee -a ${LOGFILE}
   /usr/bin/echo "*                                                        *" | tee -a ${LOGFILE}
   /usr/bin/echo "* Enter: 'quit' to exit if you are not using DB2         *" | tee -a ${LOGFILE}
   /usr/bin/echo "*        or are NOT using DB2 7.2 FP5 (7.1.0.55)         *" | tee -a ${LOGFILE}
   /usr/bin/echo "**********************************************************" | tee -a ${LOGFILE}

   read CHECK_DIR?"Enter the DB2 product install directory [Default:$DBDIR]:"

   if [[ "${CHECK_DIR}" = "quit" ]];
      then
      read JUNK?"Press enter to continue."
      exit 0
   fi

   if [[ "${CHECK_DIR}" = "" ]];
      then
      /usr/bin/echo "Using Default of $DBDIR"
      CHECK_DIR=$DBDIR
   fi

   if [[ -d ${CHECK_DIR} ]];
   then
      DBDIR=$CHECK_DIR
      /usr/bin/echo "DB HOME is $DBDIR"
   else
      /usr/bin/echo "Invalid entry of $CHECK_DIR"
      continue
   fi

   /usr/bin/echo ""
   /usr/bin/echo "copying DB2 FP5 patch to ${DBDIR}" | tee -a ${LOGFILE}

   if [[ -d ${DBDIR}/java12 ]];
   then
      /usr/bin/cp -R ${DBDIR}/java12 ${DBDIR}/java12.$$
   fi
   if [[ -d ${DBDIR}/java11 ]];
   then
      /usr/bin/cp -R ${DBDIR}/java11 ${DBDIR}/java11.$$
   fi
   /usr/bin/cp ${DBDIR}/bin/db2level ${DBDIR}/bin/db2level.$$

   /usr/bin/cp -R ${WASEFIX_SOURCE}/Software_Patches/DB2_fp5_patches/java*    ${DBDIR}
   /usr/bin/cp ${WASEFIX_SOURCE}/Software_Patches/DB2_fp5_patches/db2level    ${DBDIR}/bin

   for INSTANCES in `(${DBDIR}/instance/db2ilist)`;
   do
      while :
      do
         read CHECK_DIR?"Enter the $INSTANCES HOME directory [Default:${DBEXPORTHOME}/${INSTANCES}]:"
  
         if [[ "${CHECK_DIR}" = "quit" ]];
            then
            read JUNK?"Press enter to continue."
            exit 0
         fi

         if [[ "${CHECK_DIR}" = "" ]];
            then
            /usr/bin/echo "Using Default of ${DBEXPORTHOME}/${INSTANCES}"
            CHECK_DIR=${DBEXPORTHOME}/${INSTANCES}
         fi

         if [[ -d ${CHECK_DIR} ]];
         then
            DBINSTANCEHOME=$CHECK_DIR
            /usr/bin/echo "DB INSTANCE HOME is $DBINSTANCEHOME" | tee -a ${LOGFILE}
            break;
         else
            /usr/bin/echo "Invalid entry of $CHECK_DIR" | tee -a ${LOGFILE}
            continue
         fi
      done

      if [[ -d ${DBINSTANCEHOME} ]];
      then
         /usr/bin/echo "INSTANCE:${INSTANCES}" | tee -a ${LOGFILE}
         /usr/bin/echo "copying DB2 FP5 patch to ${DBINSTANCEHOME}/sqllib" | tee -a ${LOGFILE}

         if [[ -d ${DBINSTANCEHOME}/sqllib/java12 ]];
         then
            /usr/bin/cp -R ${DBINSTANCEHOME}/sqllib/java12 ${DBINSTANCEHOME}/sqllib/java12.$$
         fi
         if [[ -d ${DBINSTANCEHOME}/sqllib/java11 ]];
         then
            /usr/bin/cp -R ${DBINSTANCEHOME}/sqllib/java11 ${DBINSTANCEHOME}/sqllib/java11.$$
         fi

         /usr/bin/cp -R ${WASEFIX_SOURCE}/Software_Patches/DB2_fp5_patches/java*    ${DBINSTANCEHOME}/sqllib
         TEMP=`( /usr/bin/grep "usejdbc2" ${DBINSTANCEHOME}/.profile )`
         if [[ $? -ne 0 ]];
         then
            /usr/bin/echo "Adding usejdbc2 command: ${DBINSTANCEHOME}/.profile" | tee -a ${LOGFILE}
            /usr/bin/cp ${DBINSTANCEHOME}/.profile   ${DBINSTANCEHOME}/.profile.$$
            /usr/bin/sed '/^fi/a\
. ./sqllib/java12/usejdbc2' ${DBINSTANCEHOME}/.profile.$$ > ${DBINSTANCEHOME}/.profile
         else
            /usr/bin/echo "Skipping add of usejdbc2 command; present in: ${DBINSTANCEHOME}/.profile" | tee -a ${LOGFILE}
         fi
      fi
   done

   /usr/bin/echo "ENSURE that ALL DB2 Instances call the usejdbc2 in the /sqllib" | tee -a ${LOGFILE}
   /usr/bin/echo "FINISHED: DB2 FP5 eFix installation complete." | tee -a ${LOGFILE}

   break;

done

/usr/bin/echo "" | tee -a ${LOGFILE}
/usr/bin/echo "" | tee -a ${LOGFILE}


#===================  End Add by Mike  ===================
